---
layout: post
title: "Apache Arrow 0.12.0 Release"
date: "2019-01-21 07:00:00 -0600"
author: wesm
categories: [release]
---
<!--
{% comment %}
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to you under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
{% endcomment %}
-->

The Apache Arrow team is pleased to announce the 0.12.0 release. This is the
largest release yet in the project, covering 3 months of development work and
includes [**614 resolved issues**][1] from [**77 distinct contributors**][22].

See the [Install Page][2] to learn how to get the libraries for your
platform. The [complete changelog][3] is also available.

It's a huge release, but we'll give some brief highlights and new from the
project to help guide you to the parts of the project that may be of interest.

## New committers and PMC member

The Arrow team is growing! Since the 0.11.0 release we have added 3 new
committers:

* [Sebastien Binet][13], who has mainly worked on the Go implementation
* [Romain Francois][14], who has mainly worked on the R implementation
* [Yosuke Shiro][15], who has mainly worked on the GLib (C) and Ruby
  implementations

We also pleased to announce that [Krisztián Szűcs][16] has been promoted
from committer to PMC (Project Management Committee) member.

Thank you for all your contributions!

## Code donations

Since the last release, we have received 3 code donations into the Apache
project.

* A [native C# .NET library][17] donated by Feyen Zylstra LLC.
* A [Ruby library for Parquet files][18] which uses the existing GLib bindings to
  the C++ Parquet library.
* A [native Rust Parquet library][19]

We are excited to continue to grow the Apache Arrow development community.

## Combined project-level documentation

Since the last release, we have merged the Python and C++ documentation to
create a combined project-wide documentation site:
https://arrow.apache.org/docs. There is now some prose documentation about many
parts of the C++ library. We intend to keep adding documentation for other
parts of Apache Arrow to this site.

## Packages

We start providing the official APT and Yum repositories for C++ and
GLib (C). See the [install document][23] for details.

## C++ notes

Much of the C++ development work the last 3 months concerned internal code
refactoring and performance improvements. Some user-visible highlights of note:

* Experimental support for [in-memory sparse tensors (or ndarrays)][21], with
  support for zero-copy IPC
* Support for building on Alpine Linux
* Significantly improved hash table utilities, with improved hash table
  performance in many parts of the library
* IO library improvements for both read and write buffering
* A fast [trie implementation][20] for string searching
* Many improvements to the parallel CSV reader in performance and features. See
  the changelog

Since the LLVM-based Gandiva expression compiler was donated to Apache Arrow
during the last release cycle, development there has been moving along. We
expect to have Windows support for Gandiva and to ship this in downstream
packages (like Python) in the 0.13 release time frame.

## Go notes

The Arrow Go development team has been expanding. The Go library has gained
support for many missing features from the columnar format as well as semantic
constructs like chunked arrays and tables that are used heavily in the C++
project.

## GLib and Ruby notes

Development of the GLib-based C bindings and corresponding Ruby interfaces have
advanced in lock-step with the C++, Python, and R libraries. In this release,
there are many new features in C and Ruby:

* Compressed file read/write support
* Support for using the C++ parallel CSV reader
* Feather file support
* Gandiva bindings
* Plasma bindings

## Python notes

We fixed a ton of bugs and made many improvements throughout the Python
project. Some highlights from the Python side include:

* Python 3.7 support: wheels and conda packages are now available for Python
  3.7
* Substantially improved memory use when converting strings types to pandas
  format, including when reading Parquet files. Parquet users should notice
  significantly lower memory use in common use cases
* Support for reading and writing compressed files, can be used for CSV files,
  IPC, or any other form of IO
* The new `pyarrow.input_stream` and `pyarrow.output_stream` functions support
  read and write buffering. This is analogous to `BufferedIOBase` from the
  Python standard library, but the internals are implemented natively in C++.
* Gandiva (LLVM expression compiler) bindings, though not yet available in
  pip/conda yet. Look for this in 0.13.0.
* Many improvements to Arrow CUDA integration, including interoperability with
  Numba

## R notes

The R library made huge progress in 0.12, with work led by new committer Romain
Francois. The R project's features are not far behind the Python library, and
we are hoping to be able to make the R library available to CRAN users for use
with Apache Spark or for reading and writing Parquet files over the next
quarter.

Users of the `feather` R library will see significant speed increases in many
cases when reading Feather files with the new Arrow R library.

## Rust notes

Rust development had an active last 3 months; see the changelog for details.

A native Rust implementation was just donated to the project, and the community
intends to provide a similar level of functionality for reading and writing
Parquet files using the Arrow in-memory columnar format as an intermediary.

## Upcoming Roadmap, Outlook for 2019

Apache Arrow has become a large, diverse open source project. It is now being
used in dozens of downstream open source and commercial projects. Work will be
proceeding in many areas in 2019:

* Development of in-memory query execution engines (e.g. in C++, Rust)
* Expanded support for reading and writing the Apache Parquet format, and other
  common data formats like Apache Avro, CSV, JSON, and Apache ORC.
* New Flight RPC system for fast messaging of Arrow datasets
* Expanded support in existing programming languages
* New programming language bindings or native implementations

It promises to be an exciting 2019. We look forward to having you involved in
the development community.

[1]: https://issues.apache.org/jira/issues/?jql=project%20%3D%20ARROW%20AND%20status%20in%20(Resolved%2C%20Closed)%20AND%20fixVersion%20%3D%200.12.0
[2]: https://arrow.apache.org/install
[3]: https://arrow.apache.org/release/0.12.0.html
[13]: https://github.com/sbinet
[14]: https://github.com/romainfrancois
[15]: https://github.com/shiro615
[16]: https://github.com/kszucs
[17]: http://incubator.apache.org/ip-clearance/arrow-csharp-library.html
[18]: http://incubator.apache.org/ip-clearance/arrow-parquet-ruby.html
[19]: http://incubator.apache.org/ip-clearance/arrow-parquet-rust.html
[20]: https://github.com/apache/arrow/blob/master/cpp/src/arrow/util/trie.h
[21]: https://github.com/apache/arrow/blob/master/cpp/src/arrow/sparse_tensor.h
[22]: https://arrow.apache.org/release/0.12.0.html#contributors
[23]: https://arrow.apache.org/install/
